=================================
Sample networking-sfc Policy File
=================================

The following is a sample networking-sfc policy file for adaptation and use.

The sample policy can also be viewed in :download:`file form
</_static/networking-sfc.policy.yaml.sample>`.

.. important::

   The sample policy file is auto-generated from networking-sfc when this
   documentation is built. You must ensure your version of networking-sfc
   matches the version of this documentation.

.. literalinclude:: /_static/networking-sfc.policy.yaml.sample
